/****************************************************************************
** Meta object code from reading C++ file 'pixmergethread.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "utils/pixmergethread.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'pixmergethread.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14PixMergeThreadE_t {};
} // unnamed namespace

template <> constexpr inline auto PixMergeThread::qt_create_metaobjectdata<qt_meta_tag_ZN14PixMergeThreadE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PixMergeThread",
        "merageError",
        "",
        "MergeErrorValue",
        "state",
        "updatePreviewImg",
        "QImage",
        "img",
        "invalidAreaError",
        "QRect",
        "rect",
        "Failed",
        "ReachBottom",
        "MaxHeight",
        "InvalidArea",
        "RoollingTooFast"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'merageError'
        QtMocHelpers::SignalData<void(enum MergeErrorValue)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'updatePreviewImg'
        QtMocHelpers::SignalData<void(QImage)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'invalidAreaError'
        QtMocHelpers::SignalData<void(enum MergeErrorValue, QRect)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 9, 10 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'MergeErrorValue'
        QtMocHelpers::EnumData<enum MergeErrorValue>(3, 3, QMC::EnumFlags{}).add({
            {   11, MergeErrorValue::Failed },
            {   12, MergeErrorValue::ReachBottom },
            {   13, MergeErrorValue::MaxHeight },
            {   14, MergeErrorValue::InvalidArea },
            {   15, MergeErrorValue::RoollingTooFast },
        }),
    };
    return QtMocHelpers::metaObjectData<PixMergeThread, qt_meta_tag_ZN14PixMergeThreadE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PixMergeThread::staticMetaObject = { {
    QMetaObject::SuperData::link<QThread::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14PixMergeThreadE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14PixMergeThreadE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14PixMergeThreadE_t>.metaTypes,
    nullptr
} };

void PixMergeThread::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PixMergeThread *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->merageError((*reinterpret_cast<std::add_pointer_t<enum MergeErrorValue>>(_a[1]))); break;
        case 1: _t->updatePreviewImg((*reinterpret_cast<std::add_pointer_t<QImage>>(_a[1]))); break;
        case 2: _t->invalidAreaError((*reinterpret_cast<std::add_pointer_t<enum MergeErrorValue>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QRect>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PixMergeThread::*)(MergeErrorValue )>(_a, &PixMergeThread::merageError, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PixMergeThread::*)(QImage )>(_a, &PixMergeThread::updatePreviewImg, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PixMergeThread::*)(MergeErrorValue , QRect )>(_a, &PixMergeThread::invalidAreaError, 2))
            return;
    }
}

const QMetaObject *PixMergeThread::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PixMergeThread::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14PixMergeThreadE_t>.strings))
        return static_cast<void*>(this);
    return QThread::qt_metacast(_clname);
}

int PixMergeThread::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QThread::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void PixMergeThread::merageError(MergeErrorValue _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void PixMergeThread::updatePreviewImg(QImage _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void PixMergeThread::invalidAreaError(MergeErrorValue _t1, QRect _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}
QT_WARNING_POP
